PayResponseDto class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PayResponseDto({required String redirectionUrl, required String merchantTransactionReference, required String systemTransactionReference, required PaymentTransactionStatus transactionStatus, required double paidAmount})
-
PayResponseDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantTransactionReference → String
-
final
- paidAmount → double
-
final
- redirectionUrl → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemTransactionReference → String
-
final
- transactionStatus → PaymentTransactionStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited